@@ -5,7 +5,7 @@ use warnings;
 use 5.010001;
 
 # ABSTRACT: Some Perl::Critic policies used by Plicease
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 
 1;
@@ -22,7 +22,7 @@ Perl::Critic::Plicease - Some Perl::Critic policies used by Plicease
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 DESCRIPTION
 
@@ -37,6 +37,14 @@ case basis.
 
 This is a slight remix on the prohibit leading zeros policy with some helpful exceptions.
 
+=item L<Perl::Critic::Policy::Plicease::ProhibitSignaturesAndAtUnderscore>
+
+Prohibit the use of C<@_> in subroutine using signatures
+
+=item L<Perl::Critic::Policy::Plicease::ProhibitSpecificModules>
+
+Prohibit the use of specific modules or pragmas
+
 =item L<Plicease::ProhibitUnicodeDigitInRegexp|Perl::Critic::Policy::Plicease::ProhibitUnicodeDigitInRegexp>
 
 Prohibit C<\d> (match any digit) in regular expressions without the C</a> or C</u> modifier.
@@ -53,6 +61,8 @@ Ville Skyttä (SCOP)
 
 Yoshikazu Sawa (yoshikazusawa)
 
+Christian Walde (wchristian, MITHALDU)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2019-2024 by Graham Ollis.
