@@ -7,7 +7,7 @@ use Perl::Critic::Utils qw( $SEVERITY_HIGH );
 use base qw( Perl::Critic::Policy );
 
 # ABSTRACT: Prohibit the use of @_ in subroutine using signatures
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 
 use constant DESC => 'Using @_ in a function with signatures';
@@ -51,7 +51,8 @@ sub violates {
 
     my $subs = $elem->find('PPI::Statement::Sub') || [];
     foreach my $sub (@$subs) {
-      next unless defined $sub->prototype;
+      next unless( $PPI::Document::VERSION > 1.279 ?
+        @{$sub->find('PPI::Structure::Signature')} : defined $sub->prototype );
       my $symbols = $sub->find('PPI::Token::Symbol') || [];
       foreach my $symbol (@$symbols) {
         next unless $symbol->symbol eq '@_';
@@ -77,7 +78,7 @@ Perl::Critic::Policy::Plicease::ProhibitSignaturesAndAtUnderscore - Prohibit the
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -100,14 +101,16 @@ None.
 This policy can be configured to recognize additional modules as enabling the signatures feature, by
 putting an entry in a .perlcriticrc file like this:
 
- [Community::Prototypes]
- signature_enablers = Plicease::ProhibitSignaturesAndAtUnderscore
+ [Plicease::ProhibitSignaturesAndAtUnderscore]
+ signature_enablers = Foo::Bar
 
 =head1 CAVEATS
 
-This module assumes that "prototypes" detected in a source file that has signatures enabled are actually
-subroutine signatures.  This is because through static analysis alone it is not possible to determine if
-a "prototype" is really a prototype and not a signature.  There thus may be false negatives/positives.
+For older versions of L<PPI> (newer version is yet unreleased as of this writing), this module assumes
+that "prototypes" detected in a source file that has signatures enabled are actually subroutine signatures.
+This is because through static analysis alone it is not possible to determine if a "prototype" is really a
+prototype and not a signature.  There thus may be false negatives/positives.  Future versions of this module
+will require a L<PPI> with better signature detection.
 
 =head1 AUTHOR
 
@@ -119,6 +122,8 @@ Ville Skyttä (SCOP)
 
 Yoshikazu Sawa (yoshikazusawa)
 
+Christian Walde (wchristian, MITHALDU)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2019-2024 by Graham Ollis.
